@@ -1,17 +1,15 @@
 use crate::control_flow::ControlFlow;
 use crate::diagnostic::{LintDiagnostic, Position, Range};
-use crate::handler::TraverseFlow;
 use crate::ignore_directives::{
   CodeStatus, FileIgnoreDirective, LineIgnoreDirective,
 };
 use crate::rules::{get_all_rules, LintRule};
 use crate::scopes::Scope;
-use dprint_swc_ecma_ast_view::{self as AstView, BytePos, RootNode};
+use ast_view::{BytePos, RootNode, SourceFile};
 use std::collections::{HashMap, HashSet};
-use std::rc::Rc;
 use std::time::Instant;
 use swc_common::comments::Comment;
-use swc_common::{SourceMap, Span, SyntaxContext};
+use swc_common::{Span, SyntaxContext};
 
 /// `Context` stores data needed while performing all lint rules to a file.
 pub struct Context<'view> {
@@ -24,12 +22,12 @@ pub struct Context<'view> {
   /// Stores codes of plugin (user-defined) rules
   plugin_codes: HashSet<String>,
 
-  /// `SourceMap` of swc
-  source_map: Rc<SourceMap>,
+  /// Information about the file text.
+  source_file: &'view dyn SourceFile,
 
   /// The AST view of the program, which for example can be used for getting
   /// comments
-  program: AstView::Program<'view>,
+  program: ast_view::Program<'view>,
 
   /// File-level ignore directive (`deno-lint-ignore-file`)
   file_ignore_directive: Option<FileIgnoreDirective>,
@@ -55,8 +53,8 @@ impl<'view> Context<'view> {
   #[allow(clippy::too_many_arguments)]
   pub(crate) fn new(
     file_name: String,
-    source_map: Rc<SourceMap>,
-    program: AstView::Program<'view>,
+    source_file: &'view impl SourceFile,
+    program: ast_view::Program<'view>,
     file_ignore_directive: Option<FileIgnoreDirective>,
     line_ignore_directives: HashMap<usize, LineIgnoreDirective>,
     scope: Scope,
@@ -65,7 +63,7 @@ impl<'view> Context<'view> {
   ) -> Self {
     Self {
       file_name,
-      source_map,
+      source_file,
       program,
       file_ignore_directive,
       line_ignore_directives,
@@ -89,11 +87,15 @@ impl<'view> Context<'view> {
     &self.plugin_codes
   }
 
-  pub fn source_map(&self) -> Rc<SourceMap> {
-    Rc::clone(&self.source_map)
+  pub fn source_file(&self) -> &dyn SourceFile {
+    self.source_file
   }
 
-  pub fn program(&self) -> &AstView::Program<'view> {
+  pub fn file_text_substring(&self, span: &Span) -> &str {
+    &self.source_file.text()[span.lo.0 as usize..span.hi.0 as usize]
+  }
+
+  pub fn program(&self) -> &ast_view::Program<'view> {
     &self.program
   }
 
@@ -117,12 +119,16 @@ impl<'view> Context<'view> {
     self.top_level_ctxt
   }
 
-  pub(crate) fn traverse_flow(&self) -> TraverseFlow {
-    self.traverse_flow
+  pub(crate) fn assert_traverse_init(&self) {
+    self.traverse_flow.assert_init();
   }
 
-  pub(crate) fn traverse_flow_mut(&mut self) -> &mut TraverseFlow {
-    &mut self.traverse_flow
+  pub(crate) fn should_stop_traverse(&mut self) -> bool {
+    self.traverse_flow.should_stop()
+  }
+
+  pub(crate) fn stop_traverse(&mut self) {
+    self.traverse_flow.set_stop_traverse();
   }
 
   pub fn all_comments(&self) -> impl Iterator<Item = &'view Comment> {
@@ -169,12 +175,14 @@ impl<'view> Context<'view> {
         }
       }
 
-      let diagnostic_line = diagnostic.range.start.line;
-      if let Some(l) =
-        self.line_ignore_directives.get_mut(&(diagnostic_line - 1))
-      {
-        if l.check_used(&diagnostic.code) {
-          continue;
+      let diagnostic_line = diagnostic.range.start.line_index;
+      if diagnostic_line > 0 {
+        if let Some(l) =
+          self.line_ignore_directives.get_mut(&(diagnostic_line - 1))
+        {
+          if l.check_used(&diagnostic.code) {
+            continue;
+          }
         }
       }
 
@@ -325,12 +333,12 @@ impl<'view> Context<'view> {
   ) -> LintDiagnostic {
     let time_start = Instant::now();
     let start = Position::new(
-      self.source_map.lookup_byte_offset(span.lo()).pos,
-      self.source_map.lookup_char_pos(span.lo()),
+      span.lo(),
+      self.source_file.line_and_column_index(span.lo()),
     );
     let end = Position::new(
-      self.source_map.lookup_byte_offset(span.hi()).pos,
-      self.source_map.lookup_char_pos(span.hi()),
+      span.hi(),
+      self.source_file.line_and_column_index(span.hi()),
     );
 
     let diagnostic = LintDiagnostic {
@@ -353,3 +361,33 @@ impl<'view> Context<'view> {
     self.plugin_codes = codes;
   }
 }
+
+/// A struct containing a boolean value to control whether a node's children
+/// will be traversed or not.
+/// If there's no need to further traverse children nodes, you can call
+/// `ctx.stop_traverse()` from inside a handler method, which will cancel
+/// further traverse.
+#[derive(Debug, Clone, Copy, PartialEq, Eq, Default)]
+struct TraverseFlow {
+  stop_traverse: bool,
+}
+
+impl TraverseFlow {
+  fn set_stop_traverse(&mut self) {
+    self.stop_traverse = true;
+  }
+
+  fn reset(&mut self) {
+    self.stop_traverse = false;
+  }
+
+  fn assert_init(&self) {
+    assert!(!self.stop_traverse);
+  }
+
+  fn should_stop(&mut self) -> bool {
+    let stop = self.stop_traverse;
+    self.reset();
+    stop
+  }
+}
