@@ -3,8 +3,8 @@ use crate::test_util;
 use swc_common::BytePos;
 
 fn analyze_flow(src: &str) -> ControlFlow {
-  let (program, _, _, _) = test_util::parse(src);
-  ControlFlow::analyze(&program)
+  let (_, program, _, _, _) = test_util::parse(src);
+  ControlFlow::analyze((&program).into())
 }
 
 macro_rules! assert_flow {
