@@ -1,9 +1,8 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef};
+use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
-use dprint_swc_ecma_ast_view::{
-  self as AstView, Spanned, TsEntityName, TsKeywordTypeKind,
-};
+use crate::{Program, ProgramRef};
+use ast_view::{Spanned, TsEntityName, TsKeywordTypeKind};
 use if_chain::if_chain;
 use std::convert::TryFrom;
 
@@ -92,56 +91,14 @@ impl LintRule for BanTypes {
   fn lint_program_with_ast_view(
     &self,
     context: &mut Context,
-    program: AstView::Program,
+    program: Program,
   ) {
     BanTypesHandler.traverse(program, context);
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Bans the use of primitive wrapper objects (e.g. `String` the object is a
-wrapper of `string` the primitive) in addition to the non-explicit `Function`
-type and the misunderstood `Object` type.
-
-There are very few situations where primitive wrapper objects are desired and
-far more often a mistake was made with the case of the primitive type.  You also
-cannot assign a primitive wrapper object to a primitive leading to type issues
-down the line. For reference, [the TypeScript handbook] also says we shouldn't
-ever use these wrapper objects.
-
-[the TypeScript handbook]: https://www.typescriptlang.org/docs/handbook/declaration-files/do-s-and-don-ts.html#number-string-boolean-symbol-and-object
-
-With `Function`, it is better to explicitly define the entire function
-signature rather than use the non-specific `Function` type which won't give you
-type safety with the function.
-
-Finally, `Object` and `{}` means "any non-nullish value" rather than "any object
-type". `Record<string, unknown>` is a good choice for a meaning of "any object
-type". On the other hand `object` type means "any object type", but using
-`Record<string, unknown>` is much more preferable in this case too.
-
-### Invalid:
-```typescript
-let a: Boolean;
-let b: String;
-let c: Number;
-let d: Symbol;
-let e: Function;
-let f: Object;
-let g: object;
-let h: {};
-```
-
-### Valid:
-```typescript
-let a: boolean;
-let b: string;
-let c: number;
-let d: symbol;
-let e: () => number;
-let f: Record<string, unknown>;
-let g = Record<string, never>;
-```
-"#
+    include_str!("../../docs/rules/ban_types.md")
   }
 }
 
@@ -150,7 +107,7 @@ struct BanTypesHandler;
 impl Handler for BanTypesHandler {
   fn ts_type_ref(
     &mut self,
-    ts_type_ref: &AstView::TsTypeRef,
+    ts_type_ref: &ast_view::TsTypeRef,
     ctx: &mut Context,
   ) {
     if_chain! {
@@ -169,7 +126,7 @@ impl Handler for BanTypesHandler {
 
   fn ts_type_lit(
     &mut self,
-    ts_type_lit: &AstView::TsTypeLit,
+    ts_type_lit: &ast_view::TsTypeLit,
     ctx: &mut Context,
   ) {
     if ts_type_lit.members.is_empty() {
@@ -184,7 +141,7 @@ impl Handler for BanTypesHandler {
 
   fn ts_keyword_type(
     &mut self,
-    ts_keyword_type: &AstView::TsKeywordType,
+    ts_keyword_type: &ast_view::TsKeywordType,
     ctx: &mut Context,
   ) {
     if TsKeywordTypeKind::TsObjectKeyword == ts_keyword_type.keyword_kind() {
