@@ -1,8 +1,8 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef};
+use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::scopes::Scope;
-use dprint_swc_ecma_ast_view as AstView;
+use crate::{Program, ProgramRef};
 use if_chain::if_chain;
 use std::convert::TryFrom;
 use swc_atoms::JsWord;
@@ -32,102 +32,14 @@ impl LintRule for NoDeprecatedDenoApi {
   fn lint_program_with_ast_view(
     &self,
     context: &mut Context,
-    program: AstView::Program<'_>,
+    program: Program<'_>,
   ) {
     NoDeprecatedDenoApiHandler.traverse(program, context);
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Warns the usage of the deprecated Deno APIs
-
-The following APIs in `Deno` namespace are now marked as deprecated and will get
-removed from the namespace in the future.
-
-**IO APIs**
-- `Deno.Buffer`
-- `Deno.readAll`
-- `Deno.readAllSync`
-- `Deno.writeAll`
-- `Deno.writeAllSync`
-- `Deno.iter`
-- `Deno.iterSync`
-- `Deno.copy`
-
-The IO APIs are already available in `std/io`, so replace these deprecated ones
-with alternatives from `std/io`.
-For more detail, see [the tracking issue](https://github.com/denoland/deno/issues/9795).
-
-**Custom Inspector API**
-- `Deno.customInspect`
-
-`Deno.customInspect` was deprecated in favor of
-`Symbol.for("Deno.customInspect")`. Replace the usages with this symbol
-expression. See [deno#9294](https://github.com/denoland/deno/issues/9294)
-for more details.
-
-### Invalid:
-
-```typescript
-// buffer
-const a = Deno.Buffer();
-
-// read
-const b = await Deno.readAll(reader);
-const c = Deno.readAllSync(reader);
-
-// write
-await Deno.writeAll(writer, data);
-Deno.writeAllSync(writer, data);
-
-// iter
-for await (const x of Deno.iter(xs)) {}
-for (const y of Deno.iterSync(ys)) {}
-
-// copy
-await Deno.copy(reader, writer);
-
-// custom inspector
-class A {
-  [Deno.customInspect]() {
-    return "This is A";
-  }
-}
-```
-
-### Valid:
-
-```typescript
-// buffer
-import { Buffer } from "https://deno.land/std/io/buffer.ts";
-const a = new Buffer();
-
-// read
-import { readAll, readAllSync } from "https://deno.land/std/io/util.ts";
-const b = await readAll(reader);
-const c = readAllSync(reader);
-
-// write
-import { writeAll, writeAllSync } from "https://deno.land/std/io/util.ts";
-await writeAll(writer, data);
-writeAllSync(writer, data);
-
-// iter
-import { iter, iterSync } from "https://deno.land/std/io/util.ts";
-for await (const x of iter(xs)) {}
-for (const y of iterSync(ys)) {}
-
-// copy
-import { copy } from "https://deno.land/std/io/util.ts";
-await copy(reader, writer);
-
-// custom inspector
-class A {
-  [Symbol.for("Deno.customInspect")]() {
-    return "This is A";
-  }
-}
-```
-"#
+    include_str!("../../docs/rules/no_deprecated_deno_api.md")
   }
 }
 
@@ -141,8 +53,8 @@ fn is_shadowed(symbol: &JsWord, scope: &Scope) -> bool {
 
 /// Extracts a symbol from the given expression if the symbol is statically determined (otherwise,
 /// return `None`).
-fn extract_symbol<'a>(expr: &'a AstView::Expr) -> Option<&'a JsWord> {
-  use AstView::{Expr, Lit, Tpl};
+fn extract_symbol<'a>(expr: &'a ast_view::Expr) -> Option<&'a JsWord> {
+  use ast_view::{Expr, Lit, Tpl};
   match expr {
     Expr::Lit(Lit::Str(s)) => Some(s.value()),
     Expr::Ident(ident) => Some(ident.sym()),
@@ -258,15 +170,15 @@ struct NoDeprecatedDenoApiHandler;
 impl Handler for NoDeprecatedDenoApiHandler {
   fn member_expr(
     &mut self,
-    member_expr: &AstView::MemberExpr,
+    member_expr: &ast_view::MemberExpr,
     ctx: &mut Context,
   ) {
     // Not check chained member expressions (e.g. `foo.bar.baz`)
-    if member_expr.parent().is::<AstView::MemberExpr>() {
+    if member_expr.parent().is::<ast_view::MemberExpr>() {
       return;
     }
 
-    use AstView::{Expr, ExprOrSuper};
+    use ast_view::{Expr, ExprOrSuper};
     if_chain! {
       if let ExprOrSuper::Expr(Expr::Ident(obj)) = &member_expr.obj;
       let obj_symbol = obj.sym();
