@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use swc_ecmascript::ast::{
   ArrowExpr, BlockStmt, BlockStmtOrExpr, Constructor, Function, SwitchStmt,
 };
@@ -34,50 +35,9 @@ impl LintRule for NoEmpty {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Disallows the use of empty block statements.
-
-Empty block statements are legal but often represent that something was missed and can make code less readable. This rule ignores block statements that only contain comments. This rule also ignores empty constructors and function bodies (including arrow functions), which are covered by the `no-empty-function` rule.
-
-### Invalid:
-
-```typescript
-if (foo) {}
-
-while (foo) {}
-
-switch(foo) {}
-
-try {
-  doSomething();
-} catch(e) {}
-finally {}
-```
-
-### Valid:
-
-```typescript
-if (foo) {
-  // empty
-}
-
-while (foo) {
-  /* empty */
-}
-
-try {
-  doSomething();
-} catch (e) {
-  // continue regardless of error
-}
-
-try {
-  doSomething();
-} finally {
-  /* continue regardless of error */
-}
-```
-"#
+    include_str!("../../docs/rules/no_empty.md")
   }
 }
 
