@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use if_chain::if_chain;
 use swc_ecmascript::ast::{Expr, Pat, VarDecl};
 use swc_ecmascript::visit::noop_visit_type;
@@ -35,6 +36,11 @@ impl LintRule for NoThisAlias {
       ProgramRef::Script(s) => s.visit_all_with(&DUMMY_NODE, &mut visitor),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/no_this_alias.md")
+  }
 }
 
 struct NoThisAliasVisitor<'c, 'view> {
