@@ -1,6 +1,7 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
 use crate::globals::GLOBALS;
+use crate::ProgramRef;
 use swc_atoms::js_word;
 use swc_ecmascript::{
   ast::*,
@@ -42,6 +43,11 @@ impl LintRule for NoUndef {
       ProgramRef::Script(s) => s.visit_with(&DUMMY_NODE, &mut visitor),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/no_undef.md")
+  }
 }
 
 struct BindingCollector {
