@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use swc_ecmascript::ast::VarDecl;
 use swc_ecmascript::ast::VarDeclKind;
 use swc_ecmascript::visit::noop_visit_type;
@@ -32,24 +33,9 @@ impl LintRule for NoVar {
     }
   }
 
+  #[cfg(feature = "docs")]
   fn docs(&self) -> &'static str {
-    r#"Enforces the use of block scoped variables over more error prone function scoped variables. Block scoped variables are defined using `const` and `let` keywords.
-
-`const` and `let` keywords ensure the variables defined using these keywords are not accessible outside their block scope. On the other hand, variables defined using `var` keyword are only limited by their function scope.
-
-### Invalid:
-
-```typescript
-var foo = "bar";
-```
-
-### Valid:
-
-```typescript
-const foo = 1;
-let bar = 2;
-```
-"#
+    include_str!("../../docs/rules/no_var.md")
   }
 }
 
