@@ -1,5 +1,6 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use super::{Context, LintRule, ProgramRef, DUMMY_NODE};
+use super::{Context, LintRule, DUMMY_NODE};
+use crate::ProgramRef;
 use derive_more::Display;
 use std::cell::RefCell;
 use std::collections::{BTreeMap, HashMap};
@@ -69,6 +70,11 @@ impl LintRule for PreferConst {
       ProgramRef::Script(s) => visitor.visit_script(s, &DUMMY_NODE),
     }
   }
+
+  #[cfg(feature = "docs")]
+  fn docs(&self) -> &'static str {
+    include_str!("../../docs/rules/prefer_const.md")
+  }
 }
 
 type Scope = Rc<RefCell<RawScope>>;
@@ -665,14 +671,13 @@ impl<'c, 'view> PreferConstVisitor<'c, 'view> {
   }
 
   fn report(&mut self, span: Span) {
-    if let Ok(s) = self.context.source_map().span_to_snippet(span) {
-      self.context.add_diagnostic_with_hint(
-        span,
-        CODE,
-        PreferConstMessage::NeverReassigned(s),
-        PreferConstHint::UseConst,
-      );
-    }
+    let span_text = self.context.file_text_substring(&span).to_string();
+    self.context.add_diagnostic_with_hint(
+      span,
+      CODE,
+      PreferConstMessage::NeverReassigned(span_text),
+      PreferConstHint::UseConst,
+    );
   }
 
   fn with_child_scope<F, S>(&mut self, node: &S, op: F)
@@ -994,7 +999,7 @@ mod variable_collector_tests {
   use crate::test_util;
 
   fn collect(src: &str) -> VariableCollector {
-    let (program, _, _, _) = test_util::parse(src);
+    let (_, program, _, _, _) = test_util::parse(src);
     let mut v = VariableCollector::new();
     v.visit_program(&program, &program);
     v
